@@ -57,6 +57,21 @@ namespace leatherman { namespace execution {
          */
         preserve_arguments = (1 << 7),
         /**
+         * Create a new process such that it can outlive its parent. This involves running it
+         * in a separate process group on Windows, and in a separate contract on Solaris.
+         */
+        create_detached_process = (1 << 8),
+        /**
+         * Inherit locale environment variables from the current process. Limited to LC_ALL and
+         * LOCALE, which are specifically overridden to "C" with merge_environment.
+         * Will not override those variables if explicitly passed in an environment map.
+         */
+        inherit_locale = (1 << 9),
+        /**
+         * On windows, converts \r\n newlines to standard \n
+         */
+        convert_newlines = (1 << 10),
+         /**
          * A combination of all throw options.
          */
         throw_on_failure = throw_on_nonzero_exit | throw_on_signal,
@@ -194,8 +209,8 @@ namespace leatherman { namespace execution {
         /**
          * Constructor.
          */
-        result(bool s, std::string o, std::string e, int ec)
-            : success(s), output(move(o)), error(move(e)), exit_code(ec) {}
+        result(bool s, std::string o, std::string e, int ec, size_t p)
+            : success(s), output(move(o)), error(move(e)), exit_code(ec), pid(p) {}
         /**
          * Whether or not the command succeeded, defaults to true.
          */
@@ -212,6 +227,10 @@ namespace leatherman { namespace execution {
          * The process exit code, defaults to 0.
          */
         int exit_code = 0;
+        /**
+         * The process ID
+         */
+        size_t pid = 0;
     };
 
     /**
